/**
 * 
 * $Id: Manager.h,v 1.2 2000/09/23 14:51:42 amai Exp $
 *
 * Copyright (C) 1997 Free Software Foundation, Inc.
 * Copyright (C) 1997-2000 LessTif Development Team
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/

#ifndef _XM_MANAGER_H
#define _XM_MANAGER_H

#include <Xm/Xm.h>

#ifdef __cplusplus
extern "C" {
#endif

extern WidgetClass xmManagerWidgetClass;

typedef struct _XmManagerRec *XmManagerWidget;
typedef struct _XmManagerClassRec *XmManagerWidgetClass;

#ifndef XmIsManager
#define XmIsManager(w) XtIsSubclass(w, xmManagerWidgetClass)
#endif

#ifdef __cplusplus
}
#endif

#endif /* _XM_MANAGER_H */
